@@ -31,8 +31,7 @@ from . import _read_local_json
 
 
 _SERVICE_ACCOUNT_JSON = _read_local_json("url_signer_v4_test_account.json")
-_CONFORMANCE_TESTS = _read_local_json("url_signer_v4_test_data.json")
-_CLIENT_TESTS = [test for test in _CONFORMANCE_TESTS if "bucket" not in test]
+_CONFORMANCE_TESTS = _read_local_json("url_signer_v4_test_data.json")["signingV4Tests"]
 _BUCKET_TESTS = [
     test for test in _CONFORMANCE_TESTS if "bucket" in test and not test.get("object")
 ]
@@ -252,7 +251,7 @@ class Test_get_signed_query_params_v2(unittest.TestCase):
 
         expected = {
             "GoogleAccessId": account_name,
-            "Expires": str(expiration),
+            "Expires": expiration,
             "Signature": base64.b64encode(sig_bytes),
         }
         self.assertEqual(result, expected)
@@ -808,12 +807,6 @@ def _run_conformance_test(
     assert url == test_data["expectedUrl"]
 
 
-@pytest.mark.parametrize("test_data", _CLIENT_TESTS)
-@pytest.mark.skip(reason="Bucketless URLs not yet supported")
-def test_conformance_client(test_data):
-    pass  # pragma: NO COVER
-
-
 @pytest.mark.parametrize("test_data", _BUCKET_TESTS)
 def test_conformance_bucket(test_data):
     global _API_ACCESS_ENDPOINT
